-- create_mysql_store.sql
-- by Michael McLaughlin
--
-- This script demonstrates how to use SQL statements to build a DVD,
-- Game Cartridge and VHS tape store. It also highlights constraints
-- and compound check constraints and seeds the tables with data.

-- Open log file.
TEE create_mysql_store.txt

-- Conditionally drop objects.
DROP TABLE IF EXISTS system_user;

-- ------------------------------------------------------------------
-- Create SYSTEM_USER table.
-- ------------------------------------------------------------------
CREATE TABLE system_user
( system_user_id              INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, system_user_name            CHAR(20)     NOT NULL
, system_user_group_id        INT UNSIGNED NOT NULL
, system_user_type            INT UNSIGNED NOT NULL
, first_name                  CHAR(20)
, middle_name                 CHAR(20)
, last_name                   CHAR(20)
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

INSERT INTO system_user
( system_user_name
, system_user_group_id
, system_user_type
, created_by
, creation_date
, last_updated_by
, last_update_date )
VALUES
('SYSADMIN', 1, 1, 1, NOW(), 1, NOW());

-- Conditionally drop objects.
DROP TABLE IF EXISTS common_lookup;

-- ------------------------------------------------------------------
-- Create COMMON_LOOKUP table.
-- ------------------------------------------------------------------
CREATE TABLE common_lookup
( common_lookup_id            INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, common_lookup_context       CHAR(30)     NOT NULL
, common_lookup_type          CHAR(30)     NOT NULL
, common_lookup_meaning       CHAR(30)     NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('SYSTEM_USER','SYSTEM_ADMIN','System Administrator', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('SYSTEM_USER','DBA','Database Administrator', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('CONTACT','EMPLOYEE','Employee', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('CONTACT','CUSTOMER','Customer', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MEMBER','INDIVIDUAL','Individual Membership', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MEMBER','GROUP','Group Membership', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MEMBER','DISCOVER_CARD','Discover Card', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MEMBER','MASTER_CARD','Master Card', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MEMBER','VISA_CARD','VISA Card', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MULTIPLE','HOME','Home', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('MULTIPLE','WORK','Work', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','DVD_FULL_SCREEN','DVD: Full Screen', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','DVD_WIDE_SCREEN','DVD: Wide Screen', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','NINTENDO_GAMECUBE','Nintendo GameCube', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','PLAYSTATION2','PlayStation2', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','XBOX','XBOX', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','VHS_SINGLE_TAPE','VHS: Single Tape', 1, NOW(), 1, NOW());

INSERT INTO common_lookup
( common_lookup_context
, common_lookup_type
, common_lookup_meaning
, created_by
, creation_date
, last_updated_by
, last_update_date)
VALUES
('ITEM','VHS_DOUBLE_TAPE','VHS: Double Tape', 1, NOW(), 1, NOW());

-- Conditionally drop objects.
DROP TABLE IF EXISTS member;

-- ------------------------------------------------------------------
-- Create MEMBER table.
-- ------------------------------------------------------------------
CREATE TABLE member
( member_id                   INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, account_number              CHAR(10)     NOT NULL
, credit_card_number          CHAR(19)     NOT NULL
, credit_card_type            INT          NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS contact;

-- ------------------------------------------------------------------
-- Create CONTACT table.
-- ------------------------------------------------------------------
CREATE TABLE contact
( contact_id                  INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, member_id                   INT          NOT NULL
, contact_type                INT          NOT NULL
, first_name                  CHAR(20)     NOT NULL
, middle_name                 CHAR(20)
, last_name                   CHAR(20)     NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS address;

-- ------------------------------------------------------------------
-- Create ADDRESS table.
-- ------------------------------------------------------------------
CREATE TABLE address
( address_id                  INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, contact_id                  INT          NOT NULL
, address_type                INT          NOT NULL
, city                        CHAR(30)     NOT NULL
, state_province              CHAR(30)     NOT NULL
, postal_code                 CHAR(20)     NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS street_address;

-- ------------------------------------------------------------------
-- Create STREET_ADDRESS table.
-- ------------------------------------------------------------------
CREATE TABLE street_address
( street_address_id           INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, address_id                  INT          NOT NULL
, street_address              CHAR(30)     NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS telephone;

-- ------------------------------------------------------------------
-- Create TELEPHONE table.
-- ------------------------------------------------------------------
CREATE TABLE telephone
( telephone_id                INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, contact_id                  INT          NOT NULL
, address_id                  INT
, telephone_type              INT          NOT NULL
, country_code                CHAR(3)      NOT NULL
, area_code                   CHAR(6)      NOT NULL
, telephone_number            CHAR(10)     NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS rental;

-- ------------------------------------------------------------------
-- Create RENTAL table.
-- ------------------------------------------------------------------
CREATE TABLE rental
( rental_id                   INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, customer_id                 INT          NOT NULL
, check_out_date              DATE         NOT NULL
, return_date                 DATE         NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS item;

-- ------------------------------------------------------------------
-- Create ITEM table.
-- ------------------------------------------------------------------
CREATE TABLE item
( item_id                     INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, item_barcode                CHAR(14)     NOT NULL
, item_type                   INT          NOT NULL
, item_title                  CHAR(60)     NOT NULL
, item_subtitle               CHAR(60)
, item_rating                 CHAR(8)      NOT NULL
, item_release_date           DATE         NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Conditionally drop objects.
DROP TABLE IF EXISTS rental_item;

-- ------------------------------------------------------------------
-- Create RENTAL_ITEM table.
-- ------------------------------------------------------------------
CREATE TABLE rental_item
( rental_item_id              INT UNSIGNED PRIMARY KEY AUTO_INCREMENT
, rental_id                   INT          NOT NULL
, item_id                     INT          NOT NULL
, created_by                  INT          NOT NULL
, creation_date               DATE         NOT NULL
, last_updated_by             INT          NOT NULL
, last_update_date            DATE         NOT NULL);

-- Commit inserts.
COMMIT;

-- Display tables.
SHOW TABLES;

NOTEE